@@ -1,10 +1,8 @@
 package Test::YAML;
-
-use Test::Base 0.47 -Base;
+$Test::YAML::VERSION = '0.89';
+use Test::Base -Base;
 use lib 'lib';
 
-our $VERSION = '0.88';
-
 our $YAML    = 'YAML';
 our @EXPORT  = qw(
     no_diff
@@ -176,7 +174,7 @@ sub _skip_test() {
 
 #-------------------------------------------------------------------------------
 package Test::YAML::Filter;
-
+$Test::YAML::Filter::VERSION = '0.89';
 use Test::Base::Filter ();
 
 our @ISA = 'Test::Base::Filter';
@@ -234,8 +232,6 @@ sub _perl_eval_result_error_warning {
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -258,7 +254,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net.
+Copyright (c) 2006, 2011-2014. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
