@@ -1,9 +1,8 @@
 use 5.008001;
 package YAML;
+$YAML::VERSION = '0.89';
 use YAML::Mo;
 
-our $VERSION = '0.88';
-
 use Exporter;
 push @YAML::ISA, 'Exporter';
 our @EXPORT = qw{ Dump Load };
@@ -100,8 +99,6 @@ sub global_object { $global }
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -801,7 +798,7 @@ have added help along the way.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, 2006, 2008, 2011-2013. Ingy döt Net.
+Copyright (c) 2005, 2006, 2008, 2011-2014. Ingy döt Net.
 
 Copyright (c) 2001, 2002, 2005. Brian Ingerson.
 
