@@ -1,9 +1,8 @@
 package YAML::Dumper;
+$YAML::Dumper::VERSION = '0.89';
 use YAML::Mo;
 extends 'YAML::Dumper::Base';
 
-our $VERSION = '0.88';
-
 use YAML::Dumper::Base;
 use YAML::Node;
 use YAML::Types;
@@ -556,8 +555,6 @@ sub escape {
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -582,7 +579,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
