@@ -1,8 +1,7 @@
 package YAML::Dumper::Base;
+$YAML::Dumper::Base::VERSION = '0.89';
 use YAML::Mo;
 
-our $VERSION = '0.88';
-
 use YAML::Node;
 
 # YAML Dumping options
@@ -108,8 +107,6 @@ sub bless {
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -131,7 +128,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
