@@ -1,8 +1,7 @@
 package YAML::Error;
+$YAML::Error::VERSION = '0.89';
 use YAML::Mo;
 
-our $VERSION = '0.88';
-
 has 'code';
 has 'type' => default => sub {'Error'};
 has 'line';
@@ -186,13 +185,11 @@ YAML_LOAD_WARN_GLOB_IO
     );
 
 package YAML::Warning;
-
+$YAML::Warning::VERSION = '0.89';
 our @ISA = 'YAML::Error';
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -214,7 +211,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
