@@ -1,9 +1,8 @@
 package YAML::Loader;
+$YAML::Loader::VERSION = '0.89';
 use YAML::Mo;
 extends 'YAML::Loader::Base';
 
-our $VERSION = '0.88';
-
 use YAML::Loader::Base;
 use YAML::Types;
 
@@ -754,8 +753,6 @@ sub _unescape {
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -781,7 +778,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
