@@ -1,8 +1,7 @@
 package YAML::Loader::Base;
+$YAML::Loader::Base::VERSION = '0.89';
 use YAML::Mo;
 
-our $VERSION = '0.88';
-
 has load_code     => default => sub {0};
 has stream        => default => sub {''};
 has document      => default => sub {0};
@@ -33,8 +32,6 @@ sub load {
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -56,7 +53,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
