@@ -1,9 +1,6 @@
-use strict;
-use warnings;
+use strict; use warnings;
 package YAML::Tag;
-
-our $VERSION = '0.88';
-
+$YAML::Tag::VERSION = '0.89';
 use overload '""' => sub { ${$_[0]} };
 
 sub new {
@@ -21,8 +18,6 @@ sub canonical {
 
 1;
 
-__END__
-
 =encoding UTF-8
 
 =head1 NAME
@@ -43,7 +38,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006, 2011-2013. Ingy döt Net. All rights reserved.
+Copyright (c) 2006, 2011-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
